@@ -397,12 +397,6 @@ not be what you want in, e.g., shared systems like a HPC cluster.""",
         help="DEPRECATED Final volume in functional timeseries that should be "
         "considered for preprocessing.",
     )
-    g_func.add_argument(
-        "--correct-slice-timing",
-        action="store_true",
-        default=False,
-        help="Perform slice timing correction.",
-    )
 
     latest = check_latest()
     if latest is not None and currentv < latest:
@@ -430,6 +424,7 @@ discourage its usage.""",
 def parse_args(args=None, namespace=None):
     """Parse args and run further checks on the command line."""
     from logging import DEBUG
+    from contextlib import suppress
 
     from ..utils.bids import collect_bids_data
 
@@ -548,10 +543,11 @@ Please, check out your currently set filters:
             f'{", ".join(unknown_mods)}.'
         )
 
-    # Estimate the biggest file size
-    config.workflow.biggest_file_gb = _get_biggest_file_size_gb(
-        [i for sublist in config.workflow.inputs.values() for i in sublist]
-    )
+    # Estimate the biggest file size / leave 1GB if some file does not exist (datalad)
+    with suppress(FileNotFoundError):
+        config.workflow.biggest_file_gb = _get_biggest_file_size_gb(
+            [i for sublist in config.workflow.inputs.values() for i in sublist]
+        )
 
     # set specifics for alternative populations
     if opts.species.lower() != "human":
@@ -559,6 +555,10 @@ Please, check out your currently set filters:
         # TODO: add other species once rats are working
         if opts.species.lower() == "rat":
             config.workflow.template_id = "Fischer344"
+            # mean distance from the lateral edge to the center of the brain is
+            # ~ PA:10 mm, LR:7.5 mm, and IS:5 mm (see DOI: 10.1089/089771503770802853)
+            # roll movement is most likely to occur, so set to 7.5 mm
+            config.workflow.fd_radius = 7.5
             config.workflow.headmask = "NoBET"
             # block uploads for the moment; can be reversed before wider release
             config.execution.no_sub = True
